summaryrefslogtreecommitdiff
path: root/source/pdf/pdf-annot.c
diff options
context:
space:
mode:
authorTor Andersson <tor.andersson@artifex.com>2015-01-20 16:42:29 +0100
committerTor Andersson <tor.andersson@artifex.com>2015-02-17 16:36:10 +0100
commit681039767f2ccc72e236246178893eb0989169c9 (patch)
tree2eccad54c5b5bc964335dc97fe5b0fec8449d16e /source/pdf/pdf-annot.c
parent76a09166ddbe5b741f54f0fd203f2135e5b532c3 (diff)
downloadmupdf-681039767f2ccc72e236246178893eb0989169c9.tar.xz
Rename fz_close_* and fz_free_* to fz_drop_*.
Rename fz_close to fz_drop_stream. Rename fz_close_archive to fz_drop_archive. Rename fz_close_output to fz_drop_output. Rename fz_free_* to fz_drop_*. Rename pdf_free_* to pdf_drop_*. Rename xps_free_* to xps_drop_*.
Diffstat (limited to 'source/pdf/pdf-annot.c')
-rw-r--r--source/pdf/pdf-annot.c10
1 files changed, 5 insertions, 5 deletions
diff --git a/source/pdf/pdf-annot.c b/source/pdf/pdf-annot.c
index 6b786985..72f5cd8e 100644
--- a/source/pdf/pdf-annot.c
+++ b/source/pdf/pdf-annot.c
@@ -369,7 +369,7 @@ pdf_load_link_annots(pdf_document *doc, pdf_obj *annots, const fz_matrix *page_c
}
void
-pdf_free_annot(fz_context *ctx, pdf_annot *annot)
+pdf_drop_annot(fz_context *ctx, pdf_annot *annot)
{
pdf_annot *next;
@@ -500,7 +500,7 @@ pdf_load_annots(pdf_document *doc, pdf_page *page, pdf_obj *annots)
}
fz_catch(ctx)
{
- pdf_free_annot(ctx, page->annots);
+ pdf_drop_annot(ctx, page->annots);
page->annots = NULL;
fz_rethrow(ctx);
}
@@ -573,7 +573,7 @@ pdf_load_annots(pdf_document *doc, pdf_page *page, pdf_obj *annots)
{
if (fz_caught(ctx) == FZ_ERROR_TRYLATER)
{
- pdf_free_annot(ctx, page->annots);
+ pdf_drop_annot(ctx, page->annots);
page->annots = NULL;
fz_rethrow(ctx);
}
@@ -584,8 +584,8 @@ pdf_load_annots(pdf_document *doc, pdf_page *page, pdf_obj *annots)
{
/* Move to next item in the linked list, dropping this one */
*itr = annot->next;
- annot->next = NULL; /* Required because pdf_free_annot follows the "next" chain */
- pdf_free_annot(ctx, annot);
+ annot->next = NULL; /* Required because pdf_drop_annot follows the "next" chain */
+ pdf_drop_annot(ctx, annot);
}
}